import type * as gax from 'google-gax';
import type { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  BinAuthz Attestor verification
 * @class
 * @memberof v1
 */
export declare class ValidationHelperV1Client {
    private _terminated;
    private _opts;
    private _providedCustomServicePath;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    private _universeDomain;
    private _servicePath;
    private _log;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    warn: (code: string, message: string, warnType?: string) => void;
    innerApiCalls: {
        [name: string]: Function;
    };
    pathTemplates: {
        [name: string]: gax.PathTemplate;
    };
    validationHelperV1Stub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of ValidationHelperV1Client.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://cloud.google.com/docs/authentication/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP/1.1 REST mode.
     *     For more information, please check the
     *     {@link https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#http11-rest-api-mode documentation}.
     * @param {gax} [gaxInstance]: loaded instance of `google-gax`. Useful if you
     *     need to avoid loading the default gRPC version and want to use the fallback
     *     HTTP implementation. Load only fallback version and pass it to the constructor:
     *     ```
     *     const gax = require('google-gax/build/src/fallback'); // avoids loading google-gax with gRPC
     *     const client = new ValidationHelperV1Client({fallback: true}, gax);
     *     ```
     */
    constructor(opts?: ClientOptions, gaxInstance?: typeof gax | typeof gax.fallback);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @deprecated Use the apiEndpoint method of the client instance.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath.
     * @deprecated Use the apiEndpoint method of the client instance.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    get apiEndpoint(): string;
    get universeDomain(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    /**
     * Returns whether the given Attestation for the given image URI
     * was signed by the given Attestor
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.attestor
     *   Required. The resource name of the {@link protos.google.cloud.binaryauthorization.v1.Attestor|Attestor} of the
     *   {@link protos.grafeas.v1.Occurrence|occurrence}, in the format
     *   `projects/* /attestors/*`.
     * @param {grafeas.v1.AttestationOccurrence} request.attestation
     *   Required. An {@link protos.grafeas.v1.AttestationOccurrence|AttestationOccurrence} to
     *   be checked that it can be verified by the Attestor. It does not have to be
     *   an existing entity in Container Analysis. It must otherwise be a valid
     *   AttestationOccurrence.
     * @param {string} request.occurrenceNote
     *   Required. The resource name of the {@link protos.grafeas.v1.Note|Note} to which the
     *   containing {@link protos.grafeas.v1.Occurrence|Occurrence} is associated.
     * @param {string} request.occurrenceResourceUri
     *   Required. The URI of the artifact (e.g. container image) that is the
     *   subject of the containing {@link protos.grafeas.v1.Occurrence|Occurrence}.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1.ValidateAttestationOccurrenceResponse|ValidateAttestationOccurrenceResponse}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1/validation_helper_v1.validate_attestation_occurrence.js</caption>
     * region_tag:binaryauthorization_v1_generated_ValidationHelperV1_ValidateAttestationOccurrence_async
     */
    validateAttestationOccurrence(request?: protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceResponse,
        (protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest | undefined),
        {} | undefined
    ]>;
    validateAttestationOccurrence(request: protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceResponse, protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest | null | undefined, {} | null | undefined>): void;
    validateAttestationOccurrence(request: protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceResponse, protos.google.cloud.binaryauthorization.v1.IValidateAttestationOccurrenceRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Return a fully-qualified attestor resource name string.
     *
     * @param {string} project
     * @param {string} attestor
     * @returns {string} Resource name string.
     */
    attestorPath(project: string, attestor: string): string;
    /**
     * Parse the project from Attestor resource.
     *
     * @param {string} attestorName
     *   A fully-qualified path representing Attestor resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromAttestorName(attestorName: string): string | number;
    /**
     * Parse the attestor from Attestor resource.
     *
     * @param {string} attestorName
     *   A fully-qualified path representing Attestor resource.
     * @returns {string} A string representing the attestor.
     */
    matchAttestorFromAttestorName(attestorName: string): string | number;
    /**
     * Return a fully-qualified locationPolicy resource name string.
     *
     * @param {string} location
     * @returns {string} Resource name string.
     */
    locationPolicyPath(location: string): string;
    /**
     * Parse the location from LocationPolicy resource.
     *
     * @param {string} locationPolicyName
     *   A fully-qualified path representing location_policy resource.
     * @returns {string} A string representing the location.
     */
    matchLocationFromLocationPolicyName(locationPolicyName: string): string | number;
    /**
     * Return a fully-qualified project resource name string.
     *
     * @param {string} project
     * @returns {string} Resource name string.
     */
    projectPath(project: string): string;
    /**
     * Parse the project from Project resource.
     *
     * @param {string} projectName
     *   A fully-qualified path representing Project resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromProjectName(projectName: string): string | number;
    /**
     * Return a fully-qualified projectPolicy resource name string.
     *
     * @param {string} project
     * @returns {string} Resource name string.
     */
    projectPolicyPath(project: string): string;
    /**
     * Parse the project from ProjectPolicy resource.
     *
     * @param {string} projectPolicyName
     *   A fully-qualified path representing project_policy resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromProjectPolicyName(projectPolicyName: string): string | number;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
