import type * as gax from 'google-gax';
import type { Callback, CallOptions, Descriptors, ClientOptions, PaginationCallback } from 'google-gax';
import { Transform } from 'stream';
import * as protos from '../../protos/protos';
/**
 *  Google Cloud Management Service for Binary Authorization admission policies
 *  and attestation authorities.
 *
 *  This API implements a REST model with the following objects:
 *
 *  * {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|Policy}
 *  * {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}
 * @class
 * @memberof v1beta1
 */
export declare class BinauthzManagementServiceV1Beta1Client {
    private _terminated;
    private _opts;
    private _providedCustomServicePath;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    private _universeDomain;
    private _servicePath;
    private _log;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    warn: (code: string, message: string, warnType?: string) => void;
    innerApiCalls: {
        [name: string]: Function;
    };
    pathTemplates: {
        [name: string]: gax.PathTemplate;
    };
    binauthzManagementServiceV1Beta1Stub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of BinauthzManagementServiceV1Beta1Client.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://cloud.google.com/docs/authentication/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP/1.1 REST mode.
     *     For more information, please check the
     *     {@link https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#http11-rest-api-mode documentation}.
     * @param {gax} [gaxInstance]: loaded instance of `google-gax`. Useful if you
     *     need to avoid loading the default gRPC version and want to use the fallback
     *     HTTP implementation. Load only fallback version and pass it to the constructor:
     *     ```
     *     const gax = require('google-gax/build/src/fallback'); // avoids loading google-gax with gRPC
     *     const client = new BinauthzManagementServiceV1Beta1Client({fallback: true}, gax);
     *     ```
     */
    constructor(opts?: ClientOptions, gaxInstance?: typeof gax | typeof gax.fallback);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @deprecated Use the apiEndpoint method of the client instance.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath.
     * @deprecated Use the apiEndpoint method of the client instance.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    get apiEndpoint(): string;
    get universeDomain(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    /**
     * A {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy} specifies the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors} that must attest to
     * a container image, before the project is allowed to deploy that
     * image. There is at most one policy per project. All image admission
     * requests are permitted if a project has no policy.
     *
     * Gets the {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy} for this project. Returns a default
     * {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy} if the project does not have one.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.name
     *   Required. The resource name of the {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy} to retrieve,
     *   in the format `projects/* /policy`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|Policy}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.get_policy.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_GetPolicy_async
     */
    getPolicy(request?: protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IPolicy,
        (protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest | undefined),
        {} | undefined
    ]>;
    getPolicy(request: protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IPolicy, protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest | null | undefined, {} | null | undefined>): void;
    getPolicy(request: protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IPolicy, protos.google.cloud.binaryauthorization.v1beta1.IGetPolicyRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Creates or updates a project's {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy}, and returns a copy of the
     * new {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy}. A policy is always updated as a whole, to avoid race
     * conditions with concurrent policy enforcement (or management!)
     * requests. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT
     * if the request is malformed.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {google.cloud.binaryauthorization.v1beta1.Policy} request.policy
     *   Required. A new or updated {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|policy} value. The service will
     *   overwrite the {@link protos.google.cloud.binaryauthorization.v1beta1.Policy.name|policy name} field with the resource name in
     *   the request URL, in the format `projects/* /policy`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Policy|Policy}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.update_policy.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_UpdatePolicy_async
     */
    updatePolicy(request?: protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IPolicy,
        (protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest | undefined),
        {} | undefined
    ]>;
    updatePolicy(request: protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IPolicy, protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest | null | undefined, {} | null | undefined>): void;
    updatePolicy(request: protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IPolicy, protos.google.cloud.binaryauthorization.v1beta1.IUpdatePolicyRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Creates an {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}, and returns a copy of the new
     * {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}. Returns NOT_FOUND if the project does not exist,
     * INVALID_ARGUMENT if the request is malformed, ALREADY_EXISTS if the
     * {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} already exists.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. The parent of this {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}.
     * @param {string} request.attestorId
     *   Required. The {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors} ID.
     * @param {google.cloud.binaryauthorization.v1beta1.Attestor} request.attestor
     *   Required. The initial {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} value. The service will
     *   overwrite the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor.name|attestor name} field with the resource name,
     *   in the format `projects/* /attestors/*`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.create_attestor.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_CreateAttestor_async
     */
    createAttestor(request?: protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IAttestor,
        (protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest | undefined),
        {} | undefined
    ]>;
    createAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest | null | undefined, {} | null | undefined>): void;
    createAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.ICreateAttestorRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Gets an {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}.
     * Returns NOT_FOUND if the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} does not exist.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.name
     *   Required. The name of the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} to retrieve, in the format
     *   `projects/* /attestors/*`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.get_attestor.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_GetAttestor_async
     */
    getAttestor(request?: protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IAttestor,
        (protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest | undefined),
        {} | undefined
    ]>;
    getAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest | null | undefined, {} | null | undefined>): void;
    getAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.IGetAttestorRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Updates an {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}.
     * Returns NOT_FOUND if the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} does not exist.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {google.cloud.binaryauthorization.v1beta1.Attestor} request.attestor
     *   Required. The updated {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} value. The service will
     *   overwrite the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor.name|attestor name} field with the resource name
     *   in the request URL, in the format `projects/* /attestors/*`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.update_attestor.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_UpdateAttestor_async
     */
    updateAttestor(request?: protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IAttestor,
        (protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest | undefined),
        {} | undefined
    ]>;
    updateAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest, options: CallOptions, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest | null | undefined, {} | null | undefined>): void;
    updateAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest, callback: Callback<protos.google.cloud.binaryauthorization.v1beta1.IAttestor, protos.google.cloud.binaryauthorization.v1beta1.IUpdateAttestorRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Deletes an {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor}. Returns NOT_FOUND if the
     * {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestor} does not exist.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.name
     *   Required. The name of the {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors} to delete, in the format
     *   `projects/* /attestors/*`.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.protobuf.Empty|Empty}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.delete_attestor.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_DeleteAttestor_async
     */
    deleteAttestor(request?: protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest, options?: CallOptions): Promise<[
        protos.google.protobuf.IEmpty,
        (protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest | undefined),
        {} | undefined
    ]>;
    deleteAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest, options: CallOptions, callback: Callback<protos.google.protobuf.IEmpty, protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest | null | undefined, {} | null | undefined>): void;
    deleteAttestor(request: protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest, callback: Callback<protos.google.protobuf.IEmpty, protos.google.cloud.binaryauthorization.v1beta1.IDeleteAttestorRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Lists {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors}.
     * Returns INVALID_ARGUMENT if the project does not exist.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. The resource name of the project associated with the
     *   {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors}, in the format `projects/*`.
     * @param {number} request.pageSize
     *   Requested page size. The server may return fewer results than requested. If
     *   unspecified, the server will pick an appropriate default.
     * @param {string} request.pageToken
     *   A token identifying a page of results the server should return. Typically,
     *   this is the value of {@link protos.google.cloud.binaryauthorization.v1beta1.ListAttestorsResponse.next_page_token|ListAttestorsResponse.next_page_token} returned
     *   from the previous call to the `ListAttestors` method.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is Array of {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}.
     *   The client library will perform auto-pagination by default: it will call the API as many
     *   times as needed and will merge results from all the pages into this array.
     *   Note that it can affect your quota.
     *   We recommend using `listAttestorsAsync()`
     *   method described below for async iteration which you can stop as needed.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
     *   for more details and examples.
     */
    listAttestors(request?: protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.binaryauthorization.v1beta1.IAttestor[],
        protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest | null,
        protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsResponse
    ]>;
    listAttestors(request: protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, options: CallOptions, callback: PaginationCallback<protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsResponse | null | undefined, protos.google.cloud.binaryauthorization.v1beta1.IAttestor>): void;
    listAttestors(request: protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, callback: PaginationCallback<protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsResponse | null | undefined, protos.google.cloud.binaryauthorization.v1beta1.IAttestor>): void;
    /**
     * Equivalent to `listAttestors`, but returns a NodeJS Stream object.
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. The resource name of the project associated with the
     *   {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors}, in the format `projects/*`.
     * @param {number} request.pageSize
     *   Requested page size. The server may return fewer results than requested. If
     *   unspecified, the server will pick an appropriate default.
     * @param {string} request.pageToken
     *   A token identifying a page of results the server should return. Typically,
     *   this is the value of {@link protos.google.cloud.binaryauthorization.v1beta1.ListAttestorsResponse.next_page_token|ListAttestorsResponse.next_page_token} returned
     *   from the previous call to the `ListAttestors` method.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Stream}
     *   An object stream which emits an object representing {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor} on 'data' event.
     *   The client library will perform auto-pagination by default: it will call the API as many
     *   times as needed. Note that it can affect your quota.
     *   We recommend using `listAttestorsAsync()`
     *   method described below for async iteration which you can stop as needed.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
     *   for more details and examples.
     */
    listAttestorsStream(request?: protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, options?: CallOptions): Transform;
    /**
     * Equivalent to `listAttestors`, but returns an iterable object.
     *
     * `for`-`await`-`of` syntax is used with the iterable to get response elements on-demand.
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. The resource name of the project associated with the
     *   {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|attestors}, in the format `projects/*`.
     * @param {number} request.pageSize
     *   Requested page size. The server may return fewer results than requested. If
     *   unspecified, the server will pick an appropriate default.
     * @param {string} request.pageToken
     *   A token identifying a page of results the server should return. Typically,
     *   this is the value of {@link protos.google.cloud.binaryauthorization.v1beta1.ListAttestorsResponse.next_page_token|ListAttestorsResponse.next_page_token} returned
     *   from the previous call to the `ListAttestors` method.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Object}
     *   An iterable Object that allows {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols | async iteration }.
     *   When you iterate the returned iterable, each element will be an object representing
     *   {@link protos.google.cloud.binaryauthorization.v1beta1.Attestor|Attestor}. The API will be called under the hood as needed, once per the page,
     *   so you can stop the iteration when you don't need more results.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v1beta1/binauthz_management_service_v1_beta1.list_attestors.js</caption>
     * region_tag:binaryauthorization_v1beta1_generated_BinauthzManagementServiceV1Beta1_ListAttestors_async
     */
    listAttestorsAsync(request?: protos.google.cloud.binaryauthorization.v1beta1.IListAttestorsRequest, options?: CallOptions): AsyncIterable<protos.google.cloud.binaryauthorization.v1beta1.IAttestor>;
    /**
     * Return a fully-qualified attestor resource name string.
     *
     * @param {string} project
     * @param {string} attestor
     * @returns {string} Resource name string.
     */
    attestorPath(project: string, attestor: string): string;
    /**
     * Parse the project from Attestor resource.
     *
     * @param {string} attestorName
     *   A fully-qualified path representing Attestor resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromAttestorName(attestorName: string): string | number;
    /**
     * Parse the attestor from Attestor resource.
     *
     * @param {string} attestorName
     *   A fully-qualified path representing Attestor resource.
     * @returns {string} A string representing the attestor.
     */
    matchAttestorFromAttestorName(attestorName: string): string | number;
    /**
     * Return a fully-qualified locationPolicy resource name string.
     *
     * @param {string} location
     * @returns {string} Resource name string.
     */
    locationPolicyPath(location: string): string;
    /**
     * Parse the location from LocationPolicy resource.
     *
     * @param {string} locationPolicyName
     *   A fully-qualified path representing location_policy resource.
     * @returns {string} A string representing the location.
     */
    matchLocationFromLocationPolicyName(locationPolicyName: string): string | number;
    /**
     * Return a fully-qualified project resource name string.
     *
     * @param {string} project
     * @returns {string} Resource name string.
     */
    projectPath(project: string): string;
    /**
     * Parse the project from Project resource.
     *
     * @param {string} projectName
     *   A fully-qualified path representing Project resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromProjectName(projectName: string): string | number;
    /**
     * Return a fully-qualified projectPolicy resource name string.
     *
     * @param {string} project
     * @returns {string} Resource name string.
     */
    projectPolicyPath(project: string): string;
    /**
     * Parse the project from ProjectPolicy resource.
     *
     * @param {string} projectPolicyName
     *   A fully-qualified path representing project_policy resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromProjectPolicyName(projectPolicyName: string): string | number;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
